# Scripts

We have only one script as of now: **build-genbank-catalog.py**.
It is responsible to aggregate [GenBank catalogs](ftp://ftp.ncbi.nlm.nih.gov/genbank/catalog/),
remove unnecessary rows and columns so that we have a concise
table of organism names that we might be interested in.
